@@ -68,4 +68,4 @@ class REDataset(BaseDataModule):
         return parser
 
     def get_config(self):
-        return dict(num_tokens=len(self.tokenizer), num_labels=self.num_labels)
\ No newline at end of file
+        return dict(num_tokens=len(self.tokenizer), num_labels=self.num_labels, tokenizer=self.tokenizer)
\ No newline at end of file
